==> rktSNS_1.070510.tgz: rktSNS/webapp/modules/public/login/entrance.php <==
<?php
/* ========================================================================
 -  [modules/public/login/entrance.php]
 -      ログインフォーム
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 -  更新履歴：
 -      [2006/07/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'wap_public.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_public
{
    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        $this->setTemplateFile('public/login/entrance.tpl');
        $url = empty($_REQUEST['url'])? '':$_REQUEST['url'];

        $objauth = new RKT_auth();
        if ($objauth->autoLogin()){
            header('Location: '.$url);
            exit();
        }
        $objauth->logOut();

        if (!empty($_REQUEST['mismatch'])){
            $this->Assign('mismatch', true);
        }
        $this->Assign('sessionid', RKT_auth::getSessionID());
        $this->Assign('url', $url);
        $this->Assign('email', empty($_REQUEST['email'])?'':$_REQUEST['email']);
    }
} // webapp
?>

==> rktSNS_1.070830.tgz: rktSNS/webapp/modules/public/login/entrance.php <==
<?php
/* ========================================================================
 -  [modules/public/login/entrance.php]
 -      ログインフォーム
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 -  更新履歴：
 -      [2007/06/20] XSS対応
 -      [2006/07/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'wap_public.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_public
{
    /**
     * URL
     * @var integer
     */
    var $url = '';

    /**
     * メールアドレス
     * @var integer
     */
    var $email = '';
    
    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        $this->setTemplateFile('public/login/entrance.tpl');

        /* URL引数の取得 */
        $this->setSafety('url','_REQUEST','string');
        $this->setSafety('email','_REQUEST','email');

        $objauth = new RKT_auth();
        if ($objauth->autoLogin()){
            header('Location: '.$this->url);
            exit();
        }
        $objauth->logOut();

        if (!empty($_REQUEST['mismatch'])){
            $this->Assign('mismatch', true);
        }
        $this->Assign('sessionid', RKT_auth::getSessionID());
        $this->Assign('url', $this->url);
        $this->Assign('email', $this->email);
    }
} // webapp
?>
